@@ -5,6 +5,9 @@ script_path <- (function() {
   if (!length(script_path)) {
     return("R")
   }
+  if (grepl("darwin", R.version$os)) {
+    base <- gsub("~\\+~", " ", base) # on MacOS ~+~ in path denotes whitespace
+  }
   return(normalizePath(script_path))
 })()
 
